import {
  select,
  json,
  csv,
  tsv,
  geoPath,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
  zoom,
  event,
} from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

const projection = geoMercator()
  .clipExtent([
    [0, 0],
    [width, height],
  ])
  .center([140, 30])
  .scale(700);

const pathGenerator = geoPath().projection(
  projection
);

const g = svg.append('g');

svg.call(
  zoom().on('zoom', () => {
    g.attr('transform', event.transform);
  })
);

Promise.all([
  json(
    'https://raw.githubusercontent.com/samateja/D3topoJson/master/greece.json'
  ),
  json(
    'https://raw.githubusercontent.com/samateja/D3topoJson/master/greece.json'
  ),
]).then(([stateJSON, districtJSON]) => {
  const stateGroup = g.append('g');

  const states = feature(
    stateJSON,
    stateJSON.objects.greece
  );

  const colorScale = scaleOrdinal(
    schemeCategory10
  );

  const statePath = stateGroup
    .selectAll('path')
    .data(states.features);
  statePath
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('d', (d) => pathGenerator(d));
});
